@@ -62,20 +62,17 @@ SSH_KEYS_CLEANUP_PERIOD_SECONDS = SSHKeysManagerConfig.getint(
 )
 
 PlatformTokensManagerConfig = config["PlatformTokensManager"]
-BACKEND_API_CLIENT_ID_LOC = PlatformTokensManagerConfig.get(
-    "BACKEND_API_CLIENT_ID_LOC"
-)
-BACKEND_API_SECRET_LOC = PlatformTokensManagerConfig.get(
-    "BACKEND_API_SECRET_LOC"
-)
-BACKEND_API_TOKEN_LOC = PlatformTokensManagerConfig.get(
-    "BACKEND_API_TOKEN_LOC"
-)
+BACKEND_API_CLIENT_ID_LOC = PlatformTokensManagerConfig.get("BACKEND_API_CLIENT_ID_LOC")
+BACKEND_API_SECRET_LOC = PlatformTokensManagerConfig.get("BACKEND_API_SECRET_LOC")
+BACKEND_API_TOKEN_LOC = PlatformTokensManagerConfig.get("BACKEND_API_TOKEN_LOC")
 AUTH_API = PlatformTokensManagerConfig.get("AUTH_API")
 
 PlatformClusterManagerConfig = config["PlatformClusterManager"]
 BACKEND_API = PlatformClusterManagerConfig.get("BACKEND_API")
 NOTEBOOK_UUID = PlatformClusterManagerConfig.get("NOTEBOOK_UUID", None)
+AUTO_ATTACH = PlatformClusterManagerConfig.getboolean(
+    "JLAB_EXT_AUTO_ATTACH_CLUSTER", False
+)
 GET_CLUSTER_LIST_REFRESH_PERIOD_SECONDS = PlatformClusterManagerConfig.getint(
     "GET_CLUSTER_LIST_REFRESH_PERIOD_SECONDS", 30
 )
