@@ -53,3 +53,13 @@ export async function getClusterListHandler() {
   }
   return data.clusters;
 }
+
+export async function shouldAutoAttachHandler() {
+  const data: { auto_attach: boolean; e: any } = await requestAPI<any>(`bodo/autoattach`, {
+    method: 'Get',
+  });
+  if (data.e) {
+    throw new Error(data.e);
+  }
+  return data.auto_attach;
+}
