@@ -8,6 +8,7 @@ import * as React from 'react';
 import { ClusterStore } from './store';
 import { ICluster } from './types';
 import ClusterSelectList from './clusterSelect';
+import { shouldAutoAttachHandler } from './handler';
 
 interface IProps {
   store: ClusterStore;
@@ -19,12 +20,18 @@ interface IProps {
 interface IState {
   clusters: ICluster[];
   currentClusterUUID: string | null;
+  autoAttachState: boolean | null;
 }
 
 class ClusterSelect extends React.Component<IProps, IState> {
   constructor(props: IProps) {
     super(props);
-    this.state = { clusters: props.store.clusters, currentClusterUUID: null };
+    this.state = {
+      clusters: props.store.clusters,
+      currentClusterUUID: null,
+      autoAttachState: null,
+    };
+    this._tryAutoAttach();
   }
 
   componentDidMount() {
@@ -58,7 +65,10 @@ class ClusterSelect extends React.Component<IProps, IState> {
     }
   }
 
-  _onClusterUpdate(emitter: ClusterStore, newClusters: IChangedArgs<ICluster[] | undefined>): void {
+  async _onClusterUpdate(
+    emitter: ClusterStore,
+    newClusters: IChangedArgs<ICluster[] | undefined>
+  ): Promise<void> {
     const { currentClusterUUID } = this.state;
 
     let newClusterList: ICluster[];
@@ -76,7 +86,38 @@ class ClusterSelect extends React.Component<IProps, IState> {
       );
       this.props.startKernelForCluster(); // Change to no kernel
     }
-    this.setState({ clusters: newClusterList, currentClusterUUID: newCurrentClusterUUID });
+
+    this.setState({
+      clusters: newClusterList,
+      currentClusterUUID: newCurrentClusterUUID,
+    });
+
+    this._tryAutoAttach();
+  }
+
+  async _tryAutoAttach(): Promise<void> {
+    const { clusters, currentClusterUUID, autoAttachState } = this.state;
+    let autoAttach = autoAttachState;
+    let newCurrentClusterUUID = currentClusterUUID;
+
+    // If autoAttach hasn't been fetched from the backend yet
+    // fetch it. Since the response from the backend won't change
+    // only fetch it once.
+    if (autoAttachState === null) {
+      autoAttach = await shouldAutoAttachHandler();
+    }
+
+    // If the notebook isn't attached to a cluster, there is only one cluster available
+    // and is configured to have autoAttach enabled then start a kernel on the cluster
+    // and set it as the currently attached cluster
+    if (!currentClusterUUID && clusters.length === 1 && autoAttach) {
+      this.props.startKernelForCluster(clusters[0].uuid).then((success) => {
+        if (success) {
+          newCurrentClusterUUID = clusters[0].uuid;
+        }
+      });
+    }
+    this.setState({ currentClusterUUID: newCurrentClusterUUID, autoAttachState: autoAttach });
   }
 
   selectClusterCallback(clusterUUID: string) {
